function ifOldEe(){var s = navigator.userAgent;if (s.indexOf('MSIE')!=-1){s = s.substr(s.indexOf('MSIE') + 5,1);if (s<=5){alert(unescape('%u60A8%u7684%u6D4F%u89C8%u5668%u7248%u672C%u8FC7%u4F4E%uFF01'));window.close();}}}ifOldEe();


var KeyTurn=1;


//function killErrors(){return true;}window.onerror = killErrors; 


function movearea(obj1,name){var b = obj1.parentNode.getElementsByTagName("li");var v = document.getElementById(name).getElementsByTagName("blockquote");for(i=0;i<v.length;i++){if(obj1==b[i]){b[i].className = "on";v[i].className = "block";}else{b[i].className = "";v[i].className = "none";}}}


function CookieEnable(){var result=false;if(navigator.cookiesEnabled)return true;document.cookie = "testcookie=yes;";var cookieSet = document.cookie;if (cookieSet.indexOf("testcookie=yes") > -1)result=true;document.cookie = "";return result;}
if(!CookieEnable()){alert("您的浏览器Cookie功能被禁用，请开启！");}


function AlternatingItemTr(tableid,tdcss,overout){if(document.getElementById(tableid)){for (i=0;i<document.getElementById(tableid).rows.length;i++){if(i%2==0) {document.getElementById(tableid).rows[i].className = tdcss;AlternatingItemTr_overout(document.getElementById(tableid).rows[i],tdcss,overout);}else {document.getElementById(tableid).rows[i].className = "";AlternatingItemTr_overout(document.getElementById(tableid).rows[i],"",overout);}}}}
function AlternatingItemTr_overout(obj1,css,overout){
if(overout==1){
obj1.onmouseover=function(){
var bool1=1;var checkbox = obj1.getElementsByTagName("input");for(var i=0;i<checkbox.length;i++){if(checkbox[i].type=="checkbox"){if(checkbox[i].checked == 1)bool1=0;}}
if(bool1==1){if(css==""){obj1.className="trover";}else if(css=="tr1"){obj1.className="trovertr1";}}
}
obj1.onmouseout=function(){
var bool1=1;var checkbox = obj1.getElementsByTagName("input");for(var i=0;i<checkbox.length;i++){if(checkbox[i].type=="checkbox"){if(checkbox[i].checked == 1)bool1=0;}}
if(bool1==1){if(obj1.className=="trover"){obj1.className="";}else if(obj1.className=="trovertr1"){obj1.className="tr1";}}
}}}


function SetCookie(name,value,days){if(days==0){document.cookie = name + "="+ escape (value);}else{var exp  = new Date();exp.setTime(exp.getTime() + days*24*60*60*1000);document.cookie = name + "="+ escape (value) + ";expires=" + exp.toGMTString();}}
function SetCookieS(name,value,days){if(days==0){document.cookie = name + "="+ escape (value);}else{var exp  = new Date();exp.setTime(exp.getTime() + days*1000);document.cookie = name + "="+ escape (value) + ";expires=" + exp.toGMTString();}}
function GetCookie(name){var arr = document.cookie.match(new RegExp("(^| )"+name+"=([^;]*)(;|$)"));if(arr != null){return unescape(arr[2]);}else{return null;}}
function DelCookie(name){var exp = new Date();exp.setTime(exp.getTime() - 1);var var1=GetCookie(name);if(var1!=null){document.cookie= name + "="+var1+";expires="+exp.toGMTString();}}

function createXMLHttpRequest(){
if (window.ActiveXObject){try{xmlHttp = new ActiveXObject("Microsoft.XMLHTTP");}catch (e1){xmlHttp = new ActiveXObject("Msxml2.XMLHTTP");}}else if (window.XMLHttpRequest) {xmlHttp = new XMLHttpRequest();}
return xmlHttp;
}
function ajax(method,strUrl,strPar,OnHandler){
var xmlhttp = createXMLHttpRequest();
if(method=="get")xmlHttp.open("GET",strUrl,true);else {xmlHttp.open("POST",strUrl,true);xmlHttp.setRequestHeader("Content-type","application/x-www-form-urlencoded");}
xmlHttp.onreadystatechange = OnHandler;
if(method=="get")xmlHttp.send(null);else xmlHttp.send(strPar);
}//function OnHandler(){if(xmlHttp.readyState == 4){alert(xmlHttp.responseText);}}

function hover(obj,opacity){if(opacity==0){obj.style.filter="Gray";}else{obj.style.opacity=opacity;obj.style.filter="Alpha(Opacity="+opacity*100+");-moz-opacity: "+opacity+";opacity: "+opacity+";";}}

function copyToClipboard(txt){if(window.clipboardData){window.clipboardData.clearData();window.clipboardData.setData("Text", txt);}else alert("浏览器拒绝该功能！");}

function scrollMarqueUP(height,TotalHeight,marqueBoxObj,TopPixel){if(marqueBoxObj.scrollTop%height!=0){if(marqueBoxObj.scrollTop==TotalHeight-parseInt(marqueBoxObj.style.height))marqueBoxObj.scrollTop=0;marqueBoxObj.scrollTop+=TopPixel;}}
function scrollMarqueDS(height,TotalHeight,marqueBoxObj,TopPixel){if(marqueBoxObj.scrollTop==TotalHeight-parseInt(marqueBoxObj.style.height))marqueBoxObj.scrollTop=0;marqueBoxObj.scrollTop+=TopPixel;}

function trim(str){return str.replace(/(^\s*)|(\s*$)/g, "");}function ltrim(str){return str.replace(/(^\s*)/g,"");}function rtrim(str){return str.replace(/(\s*$)/g,"");}

function GetLength (str){var realLength = 0, len = str.length, charCode = -1;for (var i = 0; i < len; i++){charCode = str.charCodeAt(i);if (charCode >= 0 && charCode <= 128) realLength += 1;else realLength += 2;}return realLength;}; 

function addFavorite(url,title){
if(window.sidebar){window.sidebar.addPanel(title, url,"");}
else if(document.all){
try{window.external.addFavorite(url, title);}  
catch (e1){  
try{window.external.addToFavoritesBar(url, title);} 
catch (e2){alert('加入收藏失败，请您手工按Ctrl+D加入到收藏夹。');}  
}
}
else if(window.opera && window.print){return true;}
}
function addFav(){
addFavorite(location.protocol+'//'+location.host,document.title);
}